@@ -10,7 +10,9 @@ from naas.types import (
     t_asset,
     t_dependency,
     t_scheduler,
+    t_list,
 )
+from .env_var import n_env
 import pandas as pd
 import datetime
 import errno
@@ -26,19 +28,13 @@ filters_api = [t_notebook, t_asset]
 
 class Jobs:
     __storage_sem = None
-    __path_user_files = None
     __df = None
     __logger = None
     __naas_folder = ".naas"
     __json_name = "jobs.json"
 
     def __init__(self, logger, clean=False, init_data=[]):
-        self.__path_user_files = os.environ.get(
-            "JUPYTER_SERVER_ROOT", f'/home/{os.environ.get("NB_USER", "ftp")}'
-        )
-        self.__path_naas_files = os.path.join(
-            self.__path_user_files, self.__naas_folder
-        )
+        self.__path_naas_files = os.path.join(n_env.server_root, self.__naas_folder)
         self.__json_secrets_path = os.path.join(
             self.__path_naas_files, self.__json_name
         )
@@ -159,14 +155,18 @@ class Jobs:
                 print("find_by_value", e)
             return res
 
-    async def find_by_path(self, uid, filepath, target_type):
+    async def find_by_path(self, uid, filepath, target_type=None):
         res = None
         async with self.__storage_sem:
             try:
                 if len(self.__df) > 0:
-                    cur_jobs = self.__df[
-                        (self.__df.type == target_type) & (self.__df.path == filepath)
-                    ]
+                    if target_type:
+                        cur_jobs = self.__df[
+                            (self.__df.type == target_type)
+                            & (self.__df.path == filepath)
+                        ]
+                    else:
+                        cur_jobs = self.__df[(self.__df.path == filepath)]
                     cur_job = cur_jobs.to_dict("records")
                     if len(cur_job) > 0:
                         res = cur_job[0]
@@ -186,58 +186,140 @@ class Jobs:
             print("is_running", e)
         return res
 
-    async def list(self, uid):
+    def __match_clear(self, cur_filename, filename, clear_all):
+        if clear_all and cur_filename.endwith(filename):
+            return True
+        elif not clear_all and cur_filename == filename:
+            return True
+        else:
+            return False
+
+    def clear_file(self, uid, path, histo):
+        # possible format
+        # histo_filename
+        # out_filename
+        # histo_out_filename
+        filename = None
+        clear_all = False
+        if histo and histo == "all":
+            clear_all = True
+        elif histo:
+            filename = f"{histo}_{os.path.basename(path)}"
+        else:
+            filename = os.path.basename(path)
+        removed = []
+        dirname = os.path.dirname(path)
+        if os.path.exists(path):
+            for ffile in os.listdir(dirname):
+                if self.__match_clear(ffile, filename, clear_all):
+                    tmp_path = os.path.join(dirname, ffile)
+                    removed.append(tmp_path)
+                    self.__logger.info(
+                        {
+                            "id": uid,
+                            "filename": filename,
+                            "histo": histo,
+                            "type": "clear_file",
+                            "status": t_delete,
+                            "filepath": path,
+                        }
+                    )
+                    os.remove(tmp_path)
+        return removed
+
+    def list_files(self, uid, path, filetype, output=False):
+        d = []
+        dirname = os.path.dirname(path)
+        filename = os.path.basename(path)
+        if output:
+            filename = f"output_{filetype}_{filename}"
+        else:
+            filename = f"{filetype}_{filename}"
+        for ffile in os.listdir(dirname):
+            if ffile.endswith(filename):
+                histo = ffile.split("_")[0]
+                tmp_path = os.path.join(dirname, ffile)
+                d.append({"timestamp": histo, "filepath": tmp_path})
+        self.__logger.info(
+            {
+                "id": uid,
+                "type": "clear_file",
+                "filename": filename,
+                "status": t_list,
+                "filepath": path,
+            }
+        )
+        return d
+
+    async def list(self, uid, as_df=False):
         data = []
         try:
             async with self.__storage_sem:
-                data = self.__df.to_dict("records")
+                if as_df:
+                    data = self.__df
+                else:
+                    data = self.__df.to_dict("records")
         except Exception as e:
             print("list", e)
         return data
 
     def __delete(self, cur_elem, uid, path, target_type, value, params):
-        self.__logger.info(
-            {
-                "id": uid,
-                "type": target_type,
-                "value": value,
-                "status": t_delete,
-                "filepath": path,
-                "params": params,
-            }
-        )
-        self.__df = self.__df.drop(cur_elem.index)
+        try:
+            self.__logger.info(
+                {
+                    "id": uid,
+                    "type": target_type,
+                    "value": value,
+                    "status": t_delete,
+                    "filepath": path,
+                    "params": params,
+                }
+            )
+            print("drop ==> ", cur_elem.index)
+            self.__df = self.__df.drop(cur_elem.index)
+            return t_delete
+        except Exception as e:
+            print("delete", e)
+            return t_error
 
     def __add(self, uid, path, target_type, value, params, run_time):
-        now = datetime.datetime.now()
-        dt_string = now.strftime("%Y-%m-%d %H:%M:%S")
-        self.__logger.info(
-            {
+        try:
+            now = datetime.datetime.now()
+            dt_string = now.strftime("%Y-%m-%d %H:%M:%S")
+            self.__logger.info(
+                {
+                    "id": uid,
+                    "type": target_type,
+                    "value": value,
+                    "status": t_add,
+                    "filepath": path,
+                    "params": params,
+                }
+            )
+            new_row = {
                 "id": uid,
                 "type": target_type,
                 "value": value,
-                "status": t_update,
-                "filepath": path,
+                "status": t_add,
+                "path": path,
                 "params": params,
+                "nbRun": 1 if run_time > 0 else 0,
+                "lastRun": run_time,
+                "totalRun": run_time,
+                "lastUpdate": dt_string,
             }
-        )
-        new_row = {
-            "id": uid,
-            "type": target_type,
-            "value": value,
-            "status": t_add,
-            "path": path,
-            "params": params,
-            "nbRun": 1 if run_time > 0 else 0,
-            "lastRun": run_time,
-            "totalRun": run_time,
-            "lastUpdate": dt_string,
-        }
-        cur_df = self.__df.to_dict("records")
-        if len(self.__df) > 0:
-            self.__df = pd.DataFrame([*cur_df, new_row])
-        else:
-            self.__df = pd.DataFrame([new_row])
+            cur_df = self.__df.to_dict("records")
+            if len(self.__df) > 0:
+                self.__df = pd.DataFrame([*cur_df, new_row])
+            else:
+                self.__df = pd.DataFrame([new_row])
+            return t_add
+        except Exception as e:
+            print("add", e)
+            return t_error
+
+    def __clean_dup(self):
+        self.__df = self.__df.drop_duplicates(subset=["type", "value"])
 
     def __update(
         self, cur_elem, uid, path, target_type, value, params, status, run_time
@@ -271,56 +353,48 @@ class Jobs:
             self.__df.at[index, "lastRun"] = 0
             self.__df.at[index, "totalRun"] = 0
             return t_add
+        else:
+            return t_skip
 
     async def update(self, uid, path, target_type, value, params, status, run_time=0):
         data = None
         res = t_error
         async with self.__storage_sem:
             try:
-                cur_elem = self.__df[
-                    (self.__df.type == target_type) & (self.__df.path == path)
-                ]
-                dup_elem = self.__df[
-                    (self.__df.path != path)
-                    & (self.__df.type == target_type)
-                    & (self.__df.value == value)
-                ]
-                if len(dup_elem) > 0 and target_type in filters_api:
-                    self.__logger.error(
-                        {
-                            "id": uid,
-                            "type": target_type,
-                            "value": value,
-                            "status": t_error,
-                            "filepath": path,
-                            "params": params,
-                            "error": "Already exist",
-                        }
+                self.__clean_dup()
+                cur_elem = self.__df.query(
+                    f'type == "{target_type}" and path == "{path}"'
+                )
+                if len(cur_elem) == 1 and status == t_delete:
+                    res = self.__delete(cur_elem, uid, path, target_type, value, params)
+                elif len(cur_elem) == 1:
+                    res = self.__update(
+                        cur_elem,
+                        uid,
+                        path,
+                        target_type,
+                        value,
+                        params,
+                        status,
+                        run_time,
                     )
-                    return {
-                        "status": "error",
-                        "id": uid,
-                        "data": [],
-                        "error": f"type {target_type} with key {value} already exist",
-                    }
-                if len(cur_elem) == 1:
-                    if status == t_delete:
-                        self.__delete(cur_elem, uid, path, target_type, value, params)
-                    else:
-                        res = self.__update(
-                            cur_elem,
-                            uid,
-                            path,
-                            target_type,
-                            value,
-                            params,
-                            status,
-                            run_time,
-                        )
-                elif status == t_add and len(cur_elem) == 0:
-                    self.__add(uid, path, target_type, value, params, run_time)
+                elif len(cur_elem) == 0 and status == t_add:
+                    res = self.__add(uid, path, target_type, value, params, run_time)
                 else:
                     res = t_skip
+                if res == t_error:
+                    raise ServerError(
+                        {
+                            "status": "error",
+                            "id": uid,
+                            "data": [],
+                            "error": "unknow error",
+                        },
+                        status_code=500,
+                    )
+                data = self.__df.to_dict("records")
+                self.__save_to_file(uid, data)
+                return {"id": uid, "status": res, "data": data}
             except Exception as e:
                 print("cannot update", e)
                 self.__logger.error(
@@ -334,7 +408,7 @@ class Jobs:
                         "error": str(e),
                     }
                 )
-                raise ServerError({"id": uid, "error": str(e)}, status_code=500)
-            data = self.__df.to_dict("records")
-            self.__save_to_file(uid, data)
-        return {"id": uid, "status": res, "data": data}
+                raise ServerError(
+                    {"status": "error", "id": uid, "data": [], "error": str(e)},
+                    status_code=500,
+                )
