@@ -2,12 +2,19 @@ t_notebook = "notebook"
 t_asset = "asset"
 t_dependency = "dependency"
 t_scheduler = "scheduler"
+t_secret = "secret"
 
 t_job = "job"
+t_log = "log"
+
+t_output = "output"
+t_list = "list"
+t_send = "send"
 t_add = "installed"
 t_delete = "delete"
 t_update = "edited"
 t_start = "started"
+t_busy = "busy"
 t_skip = "skiped"
 t_error = "error"
 t_health = "healthy"
